sendGameEvent method
Send event to be processed by the game rules. Takes a payload json as input and returns a result.
Implementation
Future<CheckResult> sendGameEvent(Map<String, dynamic> event) async {
if (_firebaseRoomCommunicator == null) {
throw Exception("A room has not been joined.");
}
return await _firebaseRoomCommunicator!.sendGameEvent(event);
}