isOvercapacity property
bool
get
isOvercapacity
Get if the room is over the game player capacity.
Implementation
bool get isOvercapacity => players.length > game.playerLimit;
Get if the room is over the game player capacity.
bool get isOvercapacity => players.length > game.playerLimit;